@@ -3,7 +3,7 @@ package CohortExplorer;
 use strict;
 use warnings;
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 #-------
 
@@ -161,11 +161,11 @@ This command enables the user to see the history of saved commands. The user can
 
 =head1 EXAMPLES
 
- [somebody@somewhere]$ CohortExplorer --datasource=Clinical --username=administrator --password=describe (run describe command)
+ [somebody@somewhere]$ CohortExplorer --datasource=Clinical --username=administrator --password describe (run describe command)
 
- [somebody@somewhere]$ CohortExplorer -v -d Clinical -u administrator -p console (start console in verbose mode)
+ [somebody@somewhere]$ CohortExplorer -v -dClinical -uadministrator -p console (start console in verbose mode)
    
- [somebody@somewhere]$ CohortExplorer -d Clinical -u guest -p find -fi cancer diabetes (run find command with aliases)
+ [somebody@somewhere]$ CohortExplorer -dClinical -uguest -p find -fi cancer diabetes (run find command with aliases)
 
 =head1 SECURITY
 
