@@ -7,7 +7,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = 0.05;
+our $VERSION = 0.07;
 
 use CohortExplorer::Application;
 
@@ -169,11 +169,11 @@ This command enables the user to see the history of saved commands. The user can
 
 =head1 EXAMPLES
 
- [somebody@somewhere]$ CohortExplorer --datasource Clinical --username administrator --password describe (run describe command)
+ [somebody@somewhere]$ CohortExplorer --datasource=Clinical --username=administrator --password describe (run describe command)
 
- [somebody@somewhere]$ CohortExplorer -v -d Clinical -u administrator -p console (start console in verbose mode)
+ [somebody@somewhere]$ CohortExplorer -v -dClinical -uadministrator -p console (start console in verbose mode)
    
- [somebody@somewhere]$ CohortExplorer -d Clinical -u guest -p find -fi cancer diabetes (run find command with aliases)
+ [somebody@somewhere]$ CohortExplorer -dClinical -uguest -p find -fi cancer diabetes (run find command with aliases)
 
 =head1 SECURITY
 
